
![publish-pypi](https://github.com/matthewashley1/Fetch_BehrTech/workflows/publish-pypi/badge.svg)

# py_behrtech

A python wrapper for BehrTech's Mythings Central REST API. Currently supporting version 3.0.0


## License

Fetch_BehrTech is released under the [MIT](https://opensource.org/licenses/MIT) license
